Authenticators
==============

.. autosummary::
   :nosignatures:

   custodia.httpd.authenticators.SimpleCredsAuth
   custodia.httpd.authenticators.SimpleHeaderAuth
   custodia.httpd.authenticators.SimpleAuthKeys
   custodia.httpd.authenticators.SimpleClientCertAuth

.. autoclass:: custodia.httpd.authenticators.SimpleCredsAuth
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.httpd.authenticators.SimpleHeaderAuth
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.httpd.authenticators.SimpleAuthKeys
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.httpd.authenticators.SimpleClientCertAuth
    :members:
    :undoc-members:
    :show-inheritance:

